
.. blogpost::
    :title: XGBoost into python code
    :keywords: xgboost, pyxgboost, python
    :date: 2018-04-30
    :categories: modules

    Package `pyxgboost <https://github.com/KOLANICH/pyxgboost>`_
    converts a tree from :epkg:`xgboost` into a :epkg:`Python` code.
    :epkg:`Python` still needs to be used if the models
    has to be deployed but it should be faster for small models.
